/*
 *  This file is part of Personal Bug Tracker.
 *  Copyright (C) 2009, Xavier Nayrac
 *
 *  Personal Bug Tracker is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package desktopbugtracker.dialog;

import desktopbugtracker.I18N;
import desktopbugtracker.data.ApplicationConfig;
import desktopbugtracker.component.Project;
import desktopbugtracker.dao.ProjectDAO;
import desktopbugtracker.renderer.ProjectRenderer;
import desktopbugtracker.tools.*;
import java.awt.Cursor;
import java.sql.SQLException;
import java.util.Vector;
import java.util.logging.*;
import javax.swing.*;

public class DialogArchive extends javax.swing.JDialog {
    private static final int RET_CANCEL = 0;
    private static final int RET_OK = 1;

    private int returnStatus = RET_CANCEL;
    private DefaultListModel dlm;
    private Project project;

    public DialogArchive(java.awt.Frame parent, Project project) {
        super(parent, true);
        if (project == null) {
            JOptionPane.showMessageDialog(parent, I18N.getBundle("Error_:_null_project"));
            return;
        }
        dlm = new DefaultListModel();
        Vector<Project> vProject = new Vector<Project>();
        vProject = Project.readWithoutArchive();
        int selectedProject = 0;
        for (Project e : vProject) {
            dlm.addElement(e);
            if (e.pro_name.equals(project.pro_name)) {
                selectedProject = dlm.getSize() - 1;
            }
        }

        initComponents();
        this.getRootPane().setDefaultButton(okButton);
        projects.setSelectedIndex(selectedProject);

        setLocationRelativeTo(parent);
        setVisible(true);
    }

    public boolean returnStatusIsOk() {
        return returnStatus == RET_OK;
    }

    public boolean returnStatusIsCancel() {
        return returnStatus == RET_CANCEL;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        okButton = new javax.swing.JButton();
        cancelButton = new javax.swing.JButton();
        jLabel1 = new javax.swing.JLabel();
        jSeparator1 = new javax.swing.JSeparator();
        jScrollPane1 = new javax.swing.JScrollPane();
        projects = new javax.swing.JList();

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog(evt);
            }
        });

        okButton.setText("OK");
        okButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButtonActionPerformed(evt);
            }
        });

        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("desktopbugtracker/Bundle", ApplicationConfig.getLocale()); // NOI18N
        cancelButton.setText(bundle.getString("Cancel")); // NOI18N
        cancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButtonActionPerformed(evt);
            }
        });

        jLabel1.setFont(new java.awt.Font("sansserif", 0, 18)); // NOI18N
        java.util.ResourceBundle bundle1 = java.util.ResourceBundle.getBundle("desktopbugtracker/Bundle",ApplicationConfig.getLocale()); // NOI18N
        jLabel1.setText(bundle1.getString("Archive_Project")); // NOI18N

        projects.setModel(dlm);
        projects.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        projects.setCellRenderer(new ProjectRenderer());
        jScrollPane1.setViewportView(projects);

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.TRAILING)
                    .addComponent(jScrollPane1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 211, Short.MAX_VALUE)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(okButton, javax.swing.GroupLayout.PREFERRED_SIZE, 67, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(cancelButton))
                    .addComponent(jLabel1, javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jSeparator1, javax.swing.GroupLayout.Alignment.LEADING, javax.swing.GroupLayout.DEFAULT_SIZE, 211, Short.MAX_VALUE))
                .addContainerGap())
        );

        layout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {cancelButton, okButton});

        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator1, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 126, Short.MAX_VALUE)
                .addGap(27, 27, 27)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(cancelButton)
                    .addComponent(okButton))
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void okButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okButtonActionPerformed
        project = (Project) projects.getSelectedValue();
        try {
            if (ProjectDAO.isArchived(project.pro_name)) {
                String msg = I18N.getBundle("A_project_") + " " + project.pro_name + " "
                        + I18N.getBundle("_is_already_archived");
                msg += I18N.getBundle("Archiving_is_canceled");
                JOptionPane.showMessageDialog(this, msg);
                return;
            }
        } catch (SQLException ex) {
            Logger.getLogger(DialogArchive.class.getName()).log(Level.SEVERE, null, ex);
        }
        
        this.setCursor(Cursor.getPredefinedCursor(Cursor.WAIT_CURSOR));
        boolean result = false;
        try {
            Archiving archiving = new Archiving(project);
            result = archiving.archive();
        } catch (SqlTransactionException ex) {
            Logger.getLogger(DialogArchive.class.getName()).log(Level.SEVERE, null, ex);
        }
        String msg = null;
        if (result == true) {
            msg = I18N.getBundle("Project_") + " " + project.pro_name + " " + I18N.getBundle("_archived.");
        } else {
            msg = I18N.getBundle("Error_:_no_archiving_and_no_deletion.");
        }
        this.setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
        JOptionPane.showMessageDialog(this, msg);
        doClose(RET_OK);
    }//GEN-LAST:event_okButtonActionPerformed

    private void cancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelButtonActionPerformed
        doClose(RET_CANCEL);
    }//GEN-LAST:event_cancelButtonActionPerformed

    private void closeDialog(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_closeDialog
        doClose(RET_CANCEL);
    }//GEN-LAST:event_closeDialog

    private void doClose(int retStatus) {
        returnStatus = retStatus;
        setVisible(false);
        dispose();
    }

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton cancelButton;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JButton okButton;
    private javax.swing.JList projects;
    // End of variables declaration//GEN-END:variables

    
}
