/*
 *  This file is part of Personal Bug Tracker.
 *  Copyright (C) 2009, Xavier Nayrac
 *
 *  Personal Bug Tracker is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package desktopbugtracker.dialog;

import desktopbugtracker.data.ApplicationConfig;
import desktopbugtracker.component.*;
import desktopbugtracker.dao.*;
import desktopbugtracker.renderer.*;
import java.sql.SQLException;
import java.util.*;
import java.util.logging.*;
import javax.swing.*;

public class DialogNewReport extends javax.swing.JDialog {

    public static final int RET_CANCEL = 0;
    public static final int RET_OK = 1;

    private DefaultComboBoxModel cbPriorityModel;
    private Project project;
    private DefaultComboBoxModel cbVersionModel;
    private DefaultComboBoxModel cbCategoryModel;
    private java.awt.Frame parent;

    public DialogNewReport(java.awt.Frame parent, boolean modal, Priority priority, Project project) throws SQLException {
        super(parent, modal);
        assert priority != null;
        assert project != null;
        this.parent = parent;
        this.project = project;
        cbPriorityModel = new DefaultComboBoxModel();
        Vector<Priority> vPriority = PriorityDAO.read();
        for (Priority e : vPriority) {
            // La priorit zro (View All) est spciale, elle ne sert que pour la
            // consultation.
            if (e.pri_number != 0) {
                cbPriorityModel.addElement(e);
            }
        }
        if (priority != null) {
            // Si c'est la priorit zro, il faut changer.
            if (priority.pri_number == 0) {
                priority = PriorityDAO.getHighestPriority();
            }
            cbPriorityModel.setSelectedItem(priority);
        }

        cbVersionModel = new DefaultComboBoxModel();

        populateVersion();

        cbCategoryModel = new DefaultComboBoxModel();
        Vector<Category> vCategory = CategoryDAO.read(project.pro_name);
       

        initComponents();

         if (vCategory.isEmpty()) {
            cbCategory.setEnabled(false);
        } else {
            for (Category e : vCategory) {
                cbCategoryModel.addElement(e);
            }
        }

        lblProjectName.setText(project.pro_name);

        this.getRootPane().setDefaultButton(okButton);
        setLocationRelativeTo(parent);
        setVisible(true);
    }

    private void populateVersion() throws SQLException {
        if (project != null) {
            cbVersionModel.removeAllElements();
            Vector<Version> vVersion = VersionDAO.read("pro_name", project.pro_name);
            for (Version e : vVersion) {
                cbVersionModel.addElement(e);
            }

        }
    }

    /** @return the return status of this dialog - one of RET_OK or RET_CANCEL */
    public int getReturnStatus() {
        return returnStatus;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        okButton = new javax.swing.JButton();
        cancelButton = new javax.swing.JButton();
        jLabel1 = new javax.swing.JLabel();
        jSeparator1 = new javax.swing.JSeparator();
        jLabel2 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        jLabel5 = new javax.swing.JLabel();
        cbVersion = new javax.swing.JComboBox();
        txtTitle = new javax.swing.JTextField();
        cbPriority = new javax.swing.JComboBox();
        jScrollPane1 = new javax.swing.JScrollPane();
        txtMessage = new javax.swing.JTextArea();
        btNewVersion = new javax.swing.JButton();
        cbCategory = new javax.swing.JComboBox();
        jLabel6 = new javax.swing.JLabel();
        lblProjectName = new javax.swing.JLabel();

        addWindowListener(new java.awt.event.WindowAdapter() {
            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog(evt);
            }
        });

        okButton.setText("OK");
        okButton.setEnabled(false);
        okButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButtonActionPerformed(evt);
            }
        });

        java.util.ResourceBundle bundle = java.util.ResourceBundle.getBundle("desktopbugtracker/Bundle", ApplicationConfig.getLocale()); // NOI18N
        cancelButton.setText(bundle.getString("Cancel")); // NOI18N
        cancelButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButtonActionPerformed(evt);
            }
        });

        jLabel1.setFont(new java.awt.Font("sansserif", 0, 18));
        jLabel1.setText(bundle.getString("New_Report")); // NOI18N

        jLabel2.setText(bundle.getString("Project_:")); // NOI18N

        jLabel3.setText(bundle.getString("Priority_:")); // NOI18N

        jLabel4.setText(bundle.getString("Title_:")); // NOI18N

        jLabel5.setText(bundle.getString("Version_:")); // NOI18N

        cbVersion.setModel(cbVersionModel);
        cbVersion.setRenderer(new VersionRenderer());

        txtTitle.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyTyped(java.awt.event.KeyEvent evt) {
                txtTitleKeyTyped(evt);
            }
        });

        cbPriority.setModel(cbPriorityModel);
        cbPriority.setRenderer(new PriorityRenderer());

        txtMessage.setColumns(20);
        txtMessage.setLineWrap(true);
        txtMessage.setRows(5);
        txtMessage.setWrapStyleWord(true);
        txtMessage.addKeyListener(new java.awt.event.KeyAdapter() {
            public void keyTyped(java.awt.event.KeyEvent evt) {
                txtMessageKeyTyped(evt);
            }
        });
        jScrollPane1.setViewportView(txtMessage);

        btNewVersion.setText(bundle.getString("New_version...")); // NOI18N
        btNewVersion.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btNewVersionActionPerformed(evt);
            }
        });

        cbCategory.setModel(cbCategoryModel);
        cbCategory.setRenderer(new CategoryRenderer());

        jLabel6.setText(bundle.getString("Category")); // NOI18N

        lblProjectName.setFont(new java.awt.Font("sansserif", 1, 12));
        lblProjectName.setText("jLabel7");

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addGap(6, 6, 6)
                .addComponent(jSeparator1, javax.swing.GroupLayout.DEFAULT_SIZE, 397, Short.MAX_VALUE)
                .addContainerGap(19, Short.MAX_VALUE))
            .addGroup(layout.createSequentialGroup()
                .addGap(6, 6, 6)
                .addComponent(jLabel1)
                .addContainerGap(343, Short.MAX_VALUE))
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(btNewVersion)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 163, Short.MAX_VALUE)
                .addComponent(okButton, javax.swing.GroupLayout.PREFERRED_SIZE, 67, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(cancelButton)
                .addGap(6, 6, 6))
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(jLabel2)
                    .addComponent(jLabel3)
                    .addComponent(jLabel5)
                    .addComponent(jLabel4)
                    .addComponent(jLabel6))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(cbCategory, javax.swing.GroupLayout.Alignment.TRAILING, 0, 335, Short.MAX_VALUE)
                    .addComponent(cbVersion, 0, 335, Short.MAX_VALUE)
                    .addComponent(txtTitle, javax.swing.GroupLayout.DEFAULT_SIZE, 335, Short.MAX_VALUE)
                    .addComponent(cbPriority, 0, 335, Short.MAX_VALUE)
                    .addComponent(lblProjectName))
                .addContainerGap())
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 402, Short.MAX_VALUE)
                .addContainerGap())
        );

        layout.linkSize(javax.swing.SwingConstants.HORIZONTAL, new java.awt.Component[] {cancelButton, okButton});

        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(jLabel1)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jSeparator1, javax.swing.GroupLayout.PREFERRED_SIZE, 10, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel2)
                    .addComponent(lblProjectName))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel5)
                    .addComponent(cbVersion, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel4)
                    .addComponent(txtTitle, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(jLabel3)
                    .addComponent(cbPriority, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(cbCategory, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(jLabel6))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 235, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(cancelButton)
                    .addComponent(okButton)
                    .addComponent(btNewVersion))
                .addContainerGap())
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void okButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_okButtonActionPerformed
        try {
            int cat_id = 0;
            if (cbCategory.isEnabled())
                cat_id = ((Category)cbCategoryModel.getSelectedItem()).cat_id;
            int bug_id = BugDAO.getNextId();
            Bug bug = new Bug(bug_id, txtTitle.getText(), new Date().getTime(), 0,
                    ((Version) cbVersionModel.getSelectedItem()).ver_name, "",
                    ((Priority) cbPriorityModel.getSelectedItem()).pri_number, project.pro_name, cat_id, 0);
            Message message = new Message(MessageDAO.getNextId(), txtMessage.getText(), new Date().getTime(),
                    new Date().getTime(), bug_id, 0);
            BugDAO.create(bug);
            MessageDAO.create(message);
        } catch (SQLException ex) {
            Logger.getLogger(DialogNewReport.class.getName()).log(Level.SEVERE, null, ex);
        }
        doClose(RET_OK);
    }//GEN-LAST:event_okButtonActionPerformed

    private void cancelButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cancelButtonActionPerformed
        doClose(RET_CANCEL);
    }//GEN-LAST:event_cancelButtonActionPerformed

    /** Closes the dialog */
    private void closeDialog(java.awt.event.WindowEvent evt) {//GEN-FIRST:event_closeDialog
        doClose(RET_CANCEL);
    }//GEN-LAST:event_closeDialog

    private void txtTitleKeyTyped(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_txtTitleKeyTyped
        checkEntries();
    }//GEN-LAST:event_txtTitleKeyTyped

    private void txtMessageKeyTyped(java.awt.event.KeyEvent evt) {//GEN-FIRST:event_txtMessageKeyTyped
        checkEntries();
    }//GEN-LAST:event_txtMessageKeyTyped

    private void checkEntries() {
        if (txtTitle.getText().equals("") 
                || txtMessage.getText().equals("")
                || cbVersionModel.getSize() == 0) {
            okButton.setEnabled(false);
        } else {
            okButton.setEnabled(true);
        }
    }

    private void btNewVersionActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btNewVersionActionPerformed

        if (project == null) {
            JOptionPane.showMessageDialog(this,
                    java.util.ResourceBundle.getBundle(
                    "desktopbugtracker/Bundle",
                    ApplicationConfig.getLocale()).getString("Error_:_there_is_no_project."));
        } else {
            try {
                DialogNewVersion dial = new DialogNewVersion(parent, true,
                        project);
                populateVersion();
            } catch (SQLException ex) {
                Logger.getLogger(DialogNewReport.class.getName()).log(
                        Level.SEVERE, null, ex);
            }
            checkEntries();
        }
    }//GEN-LAST:event_btNewVersionActionPerformed

    private void doClose(int retStatus) {
        returnStatus = retStatus;
        setVisible(false);
        dispose();
    }
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btNewVersion;
    private javax.swing.JButton cancelButton;
    private javax.swing.JComboBox cbCategory;
    private javax.swing.JComboBox cbPriority;
    private javax.swing.JComboBox cbVersion;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JSeparator jSeparator1;
    private javax.swing.JLabel lblProjectName;
    private javax.swing.JButton okButton;
    private javax.swing.JTextArea txtMessage;
    private javax.swing.JTextField txtTitle;
    // End of variables declaration//GEN-END:variables
    private int returnStatus = RET_CANCEL;
}
